.. _pecan_jsonify:

:mod:`pecan.jsonify` -- Pecan ``JSON`` Support
==============================================

The :mod:`pecan.jsonify` module includes support for ``JSON`` rule 
creation using generic functions.

.. automodule:: pecan.jsonify
  :members:
  :show-inheritance: